==> 0.0.2.tar.gz: lib/classes/Devices/oc_device.dart <==
import '../../classes/device.dart';
import 'package:xml/xml.dart';
import '../../constants.dart';
import '../classes.dart';

class OcDevice extends Device {
  OcDevice(
      {required OcDeviceParameter deviceParameter,
      required String deviceIndex,
      required String deviceName,
      required String deviceParameterType,
      required List<InterfaceMode> supportedInterfaceModes,
      required List<Device> devices})
      : super(
            deviceParameter: deviceParameter,
            devices: devices,
            deviceParameterType: deviceParameterType,
            deviceName: deviceName,
            deviceIndex: deviceIndex,
            supportedInterfaceModes: supportedInterfaceModes);

  factory OcDevice.fromDevice(Device d) {
    return OcDevice(
      deviceParameter: OcDeviceParameter.fromXML(d.deviceParameter.toXML()),
      deviceIndex: d.deviceIndex,
      deviceName: d.deviceName,
      deviceParameterType: d.deviceParameterType,
      supportedInterfaceModes: d.supportedInterfaceModes,
      devices: d.devices,
    );
  }
  Future<CuppsCommandResponse> lockDevice() async {
    CuppsCommandResponse lockRes = await lock();
    return lockRes;
    // print(lockRes);
  }

  Future<CuppsCommandResponse> unlockDevice() async {
    CuppsCommandResponse lockRes = await unlock();
    return lockRes;
    // print(lockRes);
  }
}

class OcDeviceParameter extends DeviceParameter {
  final String numCharsPerLine;
  final String numLines;
  final String style;

  OcDeviceParameter({
    required VendorModelInfo vendorModelInfo,
    required IpAndPort ipAndPort,
    required Status status,
    required this.numCharsPerLine,
    required this.numLines,
    required this.style,
  }) : super(
            vendorModelInfo: vendorModelInfo,
            ipAndPort: ipAndPort,
            status: status);

  factory OcDeviceParameter.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);

    XmlElement? vendorModelInfoElement =
        document.firstChild!.getElement("vendorModelInfo");
    XmlElement? ipAndPortElement = document.firstChild!.getElement("ipAndPort");
    XmlElement? statusElement = document.firstChild!.getElement("ocStatus");

    VendorModelInfo vendorModelInfo =
        VendorModelInfo.fromXML(vendorModelInfoElement!.toXmlString());
    IpAndPort ipAndPort = IpAndPort.fromXML(ipAndPortElement!.toXmlString());
    OcStatus status = OcStatus.fromXML(statusElement!.toXmlString());

    String numCharsPerLine = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "numCharsPerLine")
        .value;
    String numLines = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "numLines")
        .value;
    String style = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "style")
        .value;
    return OcDeviceParameter(
        vendorModelInfo: vendorModelInfo,
        ipAndPort: ipAndPort,
        status: status,
        numCharsPerLine: numCharsPerLine,
        numLines: numLines,
        style: style);
  }

  @override
  String toXML() {
    return '''
                  <ocDeviceParameter numCharsPerLine="$numCharsPerLine" numLines="$numLines" style="$style" >
                      ${vendorModelInfo.toXML()}
                      ${ipAndPort.toXML()}
                      ${status.toXML()}
                  </ocDeviceParameter>
    '''
        .trimer;
  }
}

class OcStatus extends Status {
  OcStatus({
    required String desc,
    required String init,
    required String powerOff,
    required String ready,
    required String unknown,
  }) : super(
            desc: desc,
            init: init,
            powerOff: powerOff,
            ready: ready,
            unknown: unknown);

  factory OcStatus.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    String desc = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "desc",
            orElse: orElseEmpty)
        .value;
    String init = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "init")
        .value;
    String powerOff = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "powerOff")
        .value;
    String ready = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "ready")
        .value;
    String unknown = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "unknown")
        .value;
    return OcStatus(
        desc: desc,
        init: init,
        powerOff: powerOff,
        ready: ready,
        unknown: unknown);
  }

  @override
  String toXML() {
    return '''<ocStatus desc="$desc" init="$init" powerOff="$powerOff" ready="$ready" unknown="$unknown"  />'''
        .trimer;
  }

  @override
  String get image {
    if (isOff) return AssetImages.ocIconsAddressDisconnect;
    if (isLocked) return AssetImages.ocIconsAddressLocked;
    if (isInit) return AssetImages.ocIconsAddressIn;
    if (isReady) return AssetImages.ocIconsAddressActive;
    return AssetImages.ocIconsAddressNatural;
  }
}

==> 0.0.7.tar.gz: lib/classes/Devices/oc_device.dart <==
import 'dart:developer';

import '../../classes/device.dart';
import 'package:xml/xml.dart';
import '../../constants.dart';
import '../classes.dart';

class OcDevice extends Device {
  OcDevice(
      {required OcDeviceParameter deviceParameter,
      required String deviceIndex,
      required String deviceName,
      required String deviceParameterType,
      required List<InterfaceMode> supportedInterfaceModes,
      required List<Device> devices})
      : super(
            deviceParameter: deviceParameter,
            devices: devices,
            deviceParameterType: deviceParameterType,
            deviceName: deviceName,
            deviceIndex: deviceIndex,
            supportedInterfaceModes: supportedInterfaceModes);

  factory OcDevice.fromDevice(Device d) {
    return OcDevice(
      deviceParameter: OcDeviceParameter.fromXML(d.deviceParameter.toXML()),
      deviceIndex: d.deviceIndex,
      deviceName: d.deviceName,
      deviceParameterType: d.deviceParameterType,
      supportedInterfaceModes: d.supportedInterfaceModes,
      devices: d.devices,
    );
  }
  Future<CuppsCommandResponse> lockDevice() async {
    CuppsCommandResponse lockRes = await lock();
    log("$lockRes");
    return lockRes;
  }

  Future<CuppsCommandResponse> unlockDevice() async {
    CuppsCommandResponse unlockRes = await unlock();
    log("$unlockRes");
    return unlockRes;
  }
}

class OcDeviceParameter extends DeviceParameter {
  final String numCharsPerLine;
  final String numLines;
  final String style;

  OcDeviceParameter({
    required VendorModelInfo vendorModelInfo,
    required IpAndPort ipAndPort,
    required Status status,
    required this.numCharsPerLine,
    required this.numLines,
    required this.style,
  }) : super(
            vendorModelInfo: vendorModelInfo,
            ipAndPort: ipAndPort,
            status: status);

  factory OcDeviceParameter.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);

    XmlElement? vendorModelInfoElement =
        document.firstChild!.getElement("vendorModelInfo");
    XmlElement? ipAndPortElement = document.firstChild!.getElement("ipAndPort");
    XmlElement? statusElement = document.firstChild!.getElement("ocStatus");

    VendorModelInfo vendorModelInfo =
        VendorModelInfo.fromXML(vendorModelInfoElement!.toXmlString());
    IpAndPort ipAndPort = IpAndPort.fromXML(ipAndPortElement!.toXmlString());
    OcStatus status = OcStatus.fromXML(statusElement!.toXmlString());

    String numCharsPerLine = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "numCharsPerLine")
        .value;
    String numLines = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "numLines")
        .value;
    String style = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "style")
        .value;
    return OcDeviceParameter(
        vendorModelInfo: vendorModelInfo,
        ipAndPort: ipAndPort,
        status: status,
        numCharsPerLine: numCharsPerLine,
        numLines: numLines,
        style: style);
  }

  @override
  String toXML() {
    return '''
                  <ocDeviceParameter numCharsPerLine="$numCharsPerLine" numLines="$numLines" style="$style" >
                      ${vendorModelInfo.toXML()}
                      ${ipAndPort.toXML()}
                      ${status.toXML()}
                  </ocDeviceParameter>
    '''
        .trimer;
  }
}

class OcStatus extends Status {
  OcStatus({
    required String desc,
    required String init,
    required String powerOff,
    required String ready,
    required String unknown,
  }) : super(
            desc: desc,
            init: init,
            powerOff: powerOff,
            ready: ready,
            unknown: unknown);

  factory OcStatus.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    String desc = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "desc",
            orElse: orElseEmpty)
        .value;
    String init = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "init")
        .value;
    String powerOff = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "powerOff")
        .value;
    String ready = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "ready")
        .value;
    String unknown = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "unknown")
        .value;
    return OcStatus(
        desc: desc,
        init: init,
        powerOff: powerOff,
        ready: ready,
        unknown: unknown);
  }

  @override
  String toXML() {
    return '''<ocStatus desc="$desc" init="$init" powerOff="$powerOff" ready="$ready" unknown="$unknown"  />'''
        .trimer;
  }

  @override
  String get image {
    if (isOff) return AssetImages.ocIconsAddressDisconnect;
    if (isLocked) return AssetImages.ocIconsAddressLocked;
    if (isInit) return AssetImages.ocIconsAddressIn;
    if (isReady) return AssetImages.ocIconsAddressActive;
    return AssetImages.ocIconsAddressNatural;
  }
}
